@@ -293,8 +293,8 @@ class EtreeElementPathTestCase(HelperTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTests([unittest.makeSuite(EtreeElementPathTestCase)])
-    #suite.addTests([unittest.makeSuite(ElementTreeElementPathTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(EtreeElementPathTestCase)])
+    #suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(ElementTreeElementPathTestCase)])
     return suite
 
 
