@@ -4,15 +4,12 @@
 Test cases related to ISO-Schematron parsing and validation
 """
 
-import unittest, sys, os.path
+from __future__ import absolute_import
+
+import unittest
 from lxml import isoschematron
 
-this_dir = os.path.dirname(__file__)
-if this_dir not in sys.path:
-    sys.path.insert(0, this_dir) # needed for Py3
-
-from common_imports import etree, HelperTestCase, fileInTestDir
-from common_imports import doctest, make_doctest
+from .common_imports import etree, HelperTestCase, fileInTestDir, doctest, make_doctest
 
 
 class ETreeISOSchematronTestCase(HelperTestCase):
@@ -58,6 +55,8 @@ class ETreeISOSchematronTestCase(HelperTestCase):
         schema = isoschematron.Schematron(schema)
         self.assertTrue(schema)
 
+    @unittest.skipIf(not isoschematron.schematron_schema_valid_supported,
+                     'SchematronParseError is only raised when validate_schema is true')
     def test_schematron_invalid_schema_empty(self):
         schema = self.parse('''\
 <schema xmlns="http://purl.oclc.org/dsdl/schematron" />
@@ -863,7 +862,7 @@ class ETreeISOSchematronTestCase(HelperTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTests([unittest.makeSuite(ETreeISOSchematronTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(ETreeISOSchematronTestCase)])
     suite.addTests(doctest.DocTestSuite(isoschematron))
     suite.addTests(
         [make_doctest('../../../doc/validation.txt')])
