@@ -43,6 +43,24 @@ class UnicodeTestCase(HelperTestCase):
         self.assertEqual(_bytes('\\U00026007').decode('unicode_escape'),
                          tree.text)
 
+    def test_emoji_xml(self):
+        p = etree.XML(u'<p>😄</p>')
+        self.assertEqual(u'😄', p.text)
+        if sys.version_info < (3,):
+            self.assertIn(len(p.text), [1, 2])
+        else:
+            self.assertEqual(1, len(p.text))
+
+    def test_emoji_html(self):
+        html = etree.HTML(u'<html><body><p>😄</p></body></html>')
+        p = html[0][0]
+        self.assertEqual('p', p.tag)
+        self.assertEqual(u'😄', p.text)
+        if sys.version_info < (3,):
+            self.assertIn(len(p.text), [1, 2])
+        else:
+            self.assertEqual(1, len(p.text))
+
     def test_unicode_xml_broken(self):
         uxml = ('<?xml version="1.0" encoding="UTF-8"?>' +
                 '<p>%s</p>' % uni)
@@ -169,7 +187,7 @@ class EncodingsTestCase(HelperTestCase):
         parser = etree.XMLParser(recover=True)
         if etree.LIBXML_VERSION >= (2, 12, 0):
             tree = etree.fromstring(data, parser)
-            self.assertEqual('\ufffd\ufffd\ufffd', tree.text)
+            self.assertEqual(u'\ufffd\ufffd\ufffd', tree.text)
         else:
             self.assertRaises(etree.XMLSyntaxError, etree.fromstring, data, parser)
 
@@ -211,6 +229,6 @@ class EncodingsTestCase(HelperTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTests([unittest.makeSuite(UnicodeTestCase)])
-    suite.addTests([unittest.makeSuite(EncodingsTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(UnicodeTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(EncodingsTestCase)])
     return suite
