@@ -4,6 +4,8 @@
 Test cases related to XSLT processing
 """
 
+from __future__ import absolute_import
+
 import io
 import sys
 import copy
@@ -14,10 +16,6 @@ import contextlib
 from textwrap import dedent
 from tempfile import NamedTemporaryFile, mkdtemp
 
-this_dir = os.path.dirname(__file__)
-if this_dir not in sys.path:
-    sys.path.insert(0, this_dir) # needed for Py3
-
 is_python3 = sys.version_info[0] >= 3
 
 try:
@@ -30,8 +28,10 @@ try:
 except NameError: # Python 3
     basestring = str
 
-from .common_imports import etree, BytesIO, HelperTestCase, fileInTestDir
-from .common_imports import doctest, _bytes, _str, make_doctest, skipif
+from .common_imports import (
+    etree, BytesIO, HelperTestCase, fileInTestDir, _bytes, make_doctest, skipif, SimpleFSPath
+)
+
 
 class ETreeXSLTTestCase(HelperTestCase):
     """XSLT tests etree"""
@@ -195,6 +195,19 @@ class ETreeXSLTTestCase(HelperTestCase):
                     res[0] = f.read().decode("UTF-16")
             finally:
                 os.unlink(f.name)
+    
+    def test_xslt_write_output_file_pathlike(self):
+        with self._xslt_setup() as res:
+            f = NamedTemporaryFile(delete=False)
+            try:
+                try:
+                    res[0].write_output(SimpleFSPath(f.name), compression=9)
+                finally:
+                    f.close()
+                with gzip.GzipFile(f.name) as f:
+                    res[0] = f.read().decode("UTF-16")
+            finally:
+                os.unlink(f.name)
 
     def test_xslt_write_output_file_path_urlescaped(self):
         # libxml2 should not unescape file paths.
@@ -421,7 +434,7 @@ class ETreeXSLTTestCase(HelperTestCase):
 
         st = etree.XSLT(style)
         # at least libxslt 1.1.28 produces this error, earlier ones (e.g. 1.1.18) might not ...
-        self.assertRaises(etree.XSLTApplyError, st.apply, tree)
+        self.assertRaises(etree.XSLTApplyError, st, tree)
 
     def test_xslt_multiple_parameters(self):
         tree = self.parse('<a><b>B</b><c>C</c></a>')
@@ -2077,12 +2090,12 @@ class Py3XSLTTestCase(HelperTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTests([unittest.makeSuite(ETreeXSLTTestCase)])
-    suite.addTests([unittest.makeSuite(ETreeEXSLTTestCase)])
-    suite.addTests([unittest.makeSuite(ETreeXSLTExtFuncTestCase)])
-    suite.addTests([unittest.makeSuite(ETreeXSLTExtElementTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(ETreeXSLTTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(ETreeEXSLTTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(ETreeXSLTExtFuncTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(ETreeXSLTExtElementTestCase)])
     if is_python3:
-        suite.addTests([unittest.makeSuite(Py3XSLTTestCase)])
+        suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(Py3XSLTTestCase)])
     suite.addTests(
         [make_doctest('../../../doc/extensions.txt')])
     suite.addTests(
